@@ -30,12 +30,12 @@ def download_index(bond_type: str, start: datetime.date, end: datetime.date) ->
     df = yf.download(tickers=bond_type, start=start_str, end=end_str)
     df.reset_index(inplace=True)
 
-    dates = df["Date"].values
-    close = df["Close"].values
+    dates = df["Date"].dt.date.to_list()
+    close = df["Close"].to_list()
 
     index = IndexSeries(dates, close)
     return index
-    
+
 
 if __name__ == "__main__":
     start = datetime.date(2017, 1, 1)
